=======
Credits
=======

Development Lead
----------------
* Dmytro Kazanzhy (dkazanzhy@gmail.com) - `@kazanzhy <https://github.com/kazanzhy>`_

Contributors
----
*
*

Sources
----
* Mr. TradeBot
* Robotrader Jr (mr.tradebot@gmail.com) -